@@ -213,6 +213,7 @@ define(["../notjQuery"], function ($) {
             this.nextSuggestion = setTimeout(() => {
                 let req = new XMLHttpRequest();
                 req.open('POST', this.input.dataset.suggestUrl, true);
+                req.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
                 req.setRequestHeader('Content-Type', 'application/json');
 
                 if (typeof icinga !== 'undefined') {
@@ -289,6 +290,10 @@ define(["../notjQuery"], function ($) {
                         input.title = data[name];
                     }
                 }
+
+                if (this.shouldAutoSubmit()) {
+                    $(input.form).trigger('submit', { submittedBy: input });
+                }
             }
 
             this.hideSuggestions();
@@ -455,6 +460,10 @@ define(["../notjQuery"], function ($) {
             }
         }
 
+        shouldAutoSubmit() {
+            return 'autoSubmit' in this.input.dataset;
+        }
+
         /**
          * Event listeners
          */
